@@ -1,7 +1,7 @@
 package Log::ger::Layout::Pattern;
 
-our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2019-03-26'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -140,7 +140,7 @@ Log::ger::Layout::Pattern - Pattern layout
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,7 @@ Known placeholder in format string:
  %r Number of seconds elapsed from program start to logging event
  %R Number of seconds elapsed from last logging event to current
     logging event
-           %T A stack trace of functions called
+ %T A stack trace of functions called
  %% A literal percent (%) sign
 
 =for Pod::Coverage ^(.+)$
@@ -178,8 +178,10 @@ Known placeholder in format string:
 
 L<Log::ger>
 
-Modelled after <Log::Log4perl::Layout::Pattern> but note that full compatibility
-or feature parity is not a goal. See also L<Log::Log4perl::Tiny>.
+Modelled after L<Log::Log4perl::Layout::Pattern> but note that full
+compatibility or feature parity is not a goal. See also L<Log::Log4perl::Tiny>.
+
+L<Log::ger::Layout::Pattern::Multiline>
 
 =head1 AUTHOR
 
@@ -187,7 +189,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
